@@ -1414,7 +1414,9 @@ default_create_element (GstRTSPMediaFactory * factory, const GstRTSPUrl * url)
     goto no_launch;
 
   /* parse the user provided launch line */
-  element = gst_parse_launch (priv->launch, &error);
+  element =
+      gst_parse_launch_full (priv->launch, NULL, GST_PARSE_FLAG_PLACE_IN_BIN,
+      &error);
   if (element == NULL)
     goto parse_error;
 
@@ -1467,7 +1469,9 @@ default_construct (GstRTSPMediaFactory * factory, const GstRTSPUrl * url)
   GST_RTSP_MEDIA_FACTORY_UNLOCK (factory);
 
   /* create a new empty media */
-  media = g_object_new (media_gtype, "element", element, NULL);
+  media =
+      g_object_new (media_gtype, "element", element, "transport-mode",
+      factory->priv->transport_mode, NULL);
 
   gst_rtsp_media_collect_streams (media);
 
