@@ -43,6 +43,7 @@ typedef struct _GstRTSPStreamPrivate GstRTSPStreamPrivate;
 #include "rtsp-stream-transport.h"
 #include "rtsp-address-pool.h"
 #include "rtsp-session.h"
+#include "rtsp-media.h"
 
 /**
  * GstRTSPStream:
@@ -96,6 +97,9 @@ void              gst_rtsp_stream_set_address_pool (GstRTSPStream *stream, GstRT
 GstRTSPAddressPool *
                   gst_rtsp_stream_get_address_pool (GstRTSPStream *stream);
 
+void              gst_rtsp_stream_set_multicast_iface (GstRTSPStream *stream, const gchar * multicast_iface);
+gchar *           gst_rtsp_stream_get_multicast_iface (GstRTSPStream *stream);
+
 GstRTSPAddress *  gst_rtsp_stream_reserve_address  (GstRTSPStream *stream,
                                                     const gchar * address,
                                                     guint port,
@@ -107,11 +111,15 @@ gboolean          gst_rtsp_stream_join_bin         (GstRTSPStream *stream,
                                                     GstState state);
 gboolean          gst_rtsp_stream_leave_bin        (GstRTSPStream *stream,
                                                     GstBin *bin, GstElement *rtpbin);
+GstBin *          gst_rtsp_stream_get_joined_bin   (GstRTSPStream *stream);
 
 gboolean          gst_rtsp_stream_set_blocked      (GstRTSPStream * stream,
                                                     gboolean blocked);
 gboolean          gst_rtsp_stream_is_blocking      (GstRTSPStream * stream);
 
+void              gst_rtsp_stream_set_client_side (GstRTSPStream *stream, gboolean client_side);
+gboolean          gst_rtsp_stream_is_client_side (GstRTSPStream *stream);
+
 void              gst_rtsp_stream_get_server_port  (GstRTSPStream *stream,
                                                     GstRTSPRange *server_port,
                                                     GSocketFamily family);
@@ -121,6 +129,8 @@ GstRTSPAddress *  gst_rtsp_stream_get_multicast_address (GstRTSPStream *stream,
 
 GObject *         gst_rtsp_stream_get_rtpsession   (GstRTSPStream *stream);
 
+GstElement *      gst_rtsp_stream_get_srtp_encoder (GstRTSPStream *stream);
+
 void              gst_rtsp_stream_get_ssrc         (GstRTSPStream *stream,
                                                     guint *ssrc);
 
@@ -165,6 +175,13 @@ guint             gst_rtsp_stream_get_buffer_size  (GstRTSPStream *stream);
 
 void              gst_rtsp_stream_set_pt_map                 (GstRTSPStream * stream, guint pt, GstCaps * caps);
 GstElement *      gst_rtsp_stream_request_aux_sender         (GstRTSPStream * stream, guint sessid);
+
+gboolean          gst_rtsp_stream_allocate_udp_sockets       (GstRTSPStream * stream, GSocketFamily family,
+                                                              GstRTSPTransport *transport, gboolean use_client_setttings);
+
+void                    gst_rtsp_stream_set_publish_clock_mode (GstRTSPStream * stream, GstRTSPPublishClockMode mode);
+GstRTSPPublishClockMode gst_rtsp_stream_get_publish_clock_mode (GstRTSPStream * stream);
+
 /**
  * GstRTSPStreamTransportFilterFunc:
  * @stream: a #GstRTSPStream object
@@ -193,6 +210,10 @@ GList *                gst_rtsp_stream_transport_filter  (GstRTSPStream *stream,
                                                           GstRTSPStreamTransportFilterFunc func,
                                                           gpointer user_data);
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstRTSPStream, gst_object_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_RTSP_STREAM_H__ */
